@@ -78,7 +78,7 @@ impl Converter {
             .lines()
             .map(|l| {
                 let unwrapped = l.expect("Could not parse line");
-                unwrapped.replace("\u{0000}", "\u{FFFD}")
+                unwrapped.replace('\u{0000}', "\u{FFFD}")
             })
             .collect::<Vec<String>>();
 
@@ -658,7 +658,7 @@ impl Converter {
 
             // > indicates that it is a blockquote, >! indicates a spoiler
             if line.starts_with('>') && !line.starts_with(">!") {
-                let cleaned = line.replacen(">", "", 1).replacen(" ", "", 1);
+                let cleaned = line.replacen('>', "", 1).replacen(' ', "", 1);
                 block_lines.push(cleaned);
             } else {
                 break;
@@ -707,7 +707,7 @@ impl Converter {
             }
 
             // deal with alignment rows first
-            if line.replace("|", "").replace("-", "").replace(":", "").trim() == "" {
+            if line.replace('|', "").replace('-', "").replace(':', "").trim() == "" {
                 // will use https://developer.mozilla.org/en-US/docs/Web/CSS/text-align as the way github does it is no longer valid
 
                 // alignment will impact subsequent lines, unless overwritten
@@ -865,7 +865,7 @@ impl Converter {
 
                 if line.starts_with(&leading_spaces) {
                     // if it starts with lists_indent spaces its staying in teh same li
-                    let trimmed = line.replacen(" ", "", li_indent);
+                    let trimmed = line.replacen(' ', "", li_indent);
                     li_lines.push(trimmed);
                 } else if line.is_empty() {
                     // close out teh existing list item
@@ -961,7 +961,7 @@ impl Converter {
             if block_lines.is_empty() {
                 let line_to_push = if block_excluded.contains(&"html".to_string()) || block_excluded.contains(&"html_comment".to_string()) || block_excluded.contains(&"html_cdata".to_string()) {
                     // strip first < from it, &gt;
-                    line.replacen("<", "&gt;", 1).to_string()
+                    line.replacen('<', "&gt;", 1).to_string()
                 } else {
                     line.to_string()
                 };
@@ -988,7 +988,7 @@ impl Converter {
         }
 
         if !block_lines.is_empty() {
-            let node = NodeData { tag: "p".to_string(), text: Some(block_lines.join("\n")), misc: None, contents: vec![] };
+            let node = NodeData { tag: 'p'.to_string(), text: Some(block_lines.join("\n")), misc: None, contents: vec![] };
 
             Some((node, row))
         } else {
