@@ -29,10 +29,10 @@ pub mod processing {
     }
 
     pub fn copy_css(src: &Path, dest: &Path) -> io::Result<()> {
-        copy_files(src, dest, &["css"], &[])
+        copy_files(src, dest, &["md"], &[])
     }
 
-    pub fn copy_files(src: &Path, dest: &Path, filetype: &[&str], forbidden: &[&Path]) -> io::Result<()> {
+    pub fn copy_files(src: &Path, dest: &Path, forbidden_files: &[&str], forbidden: &[&Path]) -> io::Result<()> {
         if src.is_dir() {
             if forbidden.contains(&src) {
                 return Ok(());
@@ -45,11 +45,11 @@ pub mod processing {
                     let mut dest_new = PathBuf::new();
                     dest_new.push(dest);
                     dest_new.push(entry.file_name());
-                    self::copy_files(&path, &dest_new, filetype, forbidden)?;
+                    self::copy_files(&path, &dest_new, forbidden_files, forbidden)?;
                 } else {
                     // check if it ends with .css
                     if let Some(extension) = path.extension() {
-                        if filetype.contains(&extension.to_str().unwrap_or_default()) {
+                        if !forbidden_files.contains(&extension.to_str().unwrap_or_default()) {
                             // grab the file
 
                             let dest = if let Ok(stripped) = path.clone().strip_prefix(src) {
